@@ -58,6 +58,7 @@ pre_value = ''
 version_file1 = ''
 version_file2 = ''
 nocommit = 0
+fetch_version = 0
 # Variables - Change version
 
 # Variables - Sync repository
@@ -95,7 +96,6 @@ def main(argv):
     global encoded_string 
     global url
     global debug
-    global nocommit
     # Variables - Deploy AWX
     
     # Variables - Nexus
@@ -120,6 +120,8 @@ def main(argv):
     global pre_value
     global version_file1
     global version_file2
+    global nocommit
+    global fetch_version
     # Variables - Change version
     
     global branch
@@ -149,7 +151,7 @@ def main(argv):
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=","--host=",
                                                 "format=",
-                                                "type=", "archtype=", "prevalue=","file2=","nocommit",
+                                                "type=", "archtype=", "prevalue=","file2=","nocommit","getversion",
                                                 "message=", "branch=",
                                                 "projectkey=", "projectname=",
                                                 "debug",
@@ -218,6 +220,7 @@ def main(argv):
                 print("-b, --branch        Branch to commit code changes. Default: develop")
                 print("--preValue          Prerelease version value e.g SNAPHOT, RELEASE, BUILD, beta, alpa")
                 print("--nocommit     Does not create feature branch with version change")
+                print("--getversion   Fetches the current application version")
                 print("-f, --file     File name that you want to update version number. It should be relative to artify execution directory ")
                 print("--file2        An additional file that you want to update version number. It should be relative to artify execution")
                 return sys.exit(0)
@@ -261,6 +264,8 @@ def main(argv):
             debug = 1
         elif opt == "--nocommit":
             nocommit = 1
+        elif opt == "--getversion":
+            fetch_version = 1
         elif opt in ("-c", "--command"):
             action = arg
             if action == '':
@@ -280,8 +285,8 @@ def main(argv):
                 if artifact_name2 == '':
                     print("Please specify second artifact name")
                     return sys.exit(2)
-            else:
-                print("Invalid command specified: param: --file2")   
+            # else:
+            #     print("Invalid command specified: param: --file2")   
         ## Deploy-artifact-awx-host params START
         elif opt in ("-f", "--file", "--format"):
             if action == 'nexus':
